@@ -1,3 +1,4 @@
+use std::fmt::Display;
 use std::path::{Component, Path, PathBuf};
 use std::pin::Pin;
 
@@ -9,8 +10,9 @@ use tokio_util::compat::{FuturesAsyncReadCompatExt, TokioAsyncReadCompatExt};
 use tracing::{debug, warn};
 
 use uv_distribution_filename::SourceDistExtension;
+use uv_warnings::warn_user_once;
 
-use crate::{Error, insecure_no_validate, validate_archive_member_name};
+use crate::{CompressionMethod, Error, insecure_no_validate, validate_archive_member_name};
 
 const DEFAULT_BUF_SIZE: usize = 128 * 1024;
 
@@ -43,7 +45,11 @@ struct ComputedEntry {
 /// This is useful for unzipping files as they're being downloaded. If the archive
 /// is already fully on disk, consider using `unzip_archive`, which can use multiple
 /// threads to work faster in that case.
-pub async fn unzip<R: tokio::io::AsyncRead + Unpin>(
+///
+/// `source_hint` is used for warning messages, to identify the source of the ZIP archive
+/// beneath the reader. It might be a URL, a file path, or something else.
+pub async fn unzip<D: Display, R: tokio::io::AsyncRead + Unpin>(
+    source_hint: D,
     reader: R,
     target: impl AsRef<Path>,
 ) -> Result<(), Error> {
@@ -79,8 +85,22 @@ pub async fn unzip<R: tokio::io::AsyncRead + Unpin>(
     let mut offset = 0;
 
     while let Some(mut entry) = zip.next_with_entry().await? {
+        let zip_entry = entry.reader().entry();
+
+        // Check for unexpected compression methods.
+        // A future version of uv will reject instead of warning about these.
+        let compression = CompressionMethod::from(zip_entry.compression());
+        if !compression.is_well_known() {
+            warn_user_once!(
+                "One or more file entries in '{source_hint}' use the '{compression}' compression method, which is not widely supported. A future version of uv will reject ZIP archives containing entries compressed with this method. Entries must be compressed with the '{stored}', '{deflate}', or '{zstd}' compression methods.",
+                stored = CompressionMethod::Stored,
+                deflate = CompressionMethod::Deflated,
+                zstd = CompressionMethod::Zstd,
+            );
+        }
+
         // Construct the (expected) path to the file on-disk.
-        let path = match entry.reader().entry().filename().as_str() {
+        let path = match zip_entry.filename().as_str() {
             Ok(path) => path,
             Err(ZipError::StringNotUtf8) => return Err(Error::LocalHeaderNotUtf8 { offset }),
             Err(err) => return Err(err.into()),
@@ -107,14 +127,14 @@ pub async fn unzip<R: tokio::io::AsyncRead + Unpin>(
             continue;
         };
 
-        let file_offset = entry.reader().entry().file_offset();
-        let expected_compressed_size = entry.reader().entry().compressed_size();
-        let expected_uncompressed_size = entry.reader().entry().uncompressed_size();
-        let expected_data_descriptor = entry.reader().entry().data_descriptor();
+        let file_offset = zip_entry.file_offset();
+        let expected_compressed_size = zip_entry.compressed_size();
+        let expected_uncompressed_size = zip_entry.uncompressed_size();
+        let expected_data_descriptor = zip_entry.data_descriptor();
 
         // Either create the directory or write the file to disk.
         let path = target.join(&relpath);
-        let is_dir = entry.reader().entry().dir()?;
+        let is_dir = zip_entry.dir()?;
         let computed = if is_dir {
             if directories.insert(path.clone()) {
                 fs_err::tokio::create_dir_all(path)
@@ -123,23 +143,23 @@ pub async fn unzip<R: tokio::io::AsyncRead + Unpin>(
             }
 
             // If this is a directory, we expect the CRC32 to be 0.
-            if entry.reader().entry().crc32() != 0 {
+            if zip_entry.crc32() != 0 {
                 if !skip_validation {
                     return Err(Error::BadCrc32 {
                         path: relpath.clone(),
                         computed: 0,
-                        expected: entry.reader().entry().crc32(),
+                        expected: zip_entry.crc32(),
                     });
                 }
             }
 
             // If this is a directory, we expect the uncompressed size to be 0.
-            if entry.reader().entry().uncompressed_size() != 0 {
+            if zip_entry.uncompressed_size() != 0 {
                 if !skip_validation {
                     return Err(Error::BadUncompressedSize {
                         path: relpath.clone(),
                         computed: 0,
-                        expected: entry.reader().entry().uncompressed_size(),
+                        expected: zip_entry.uncompressed_size(),
                     });
                 }
             }
@@ -164,7 +184,7 @@ pub async fn unzip<R: tokio::io::AsyncRead + Unpin>(
             {
                 Ok(file) => {
                     // Write the file to disk.
-                    let size = entry.reader().entry().uncompressed_size();
+                    let size = zip_entry.uncompressed_size();
                     let mut writer = if let Ok(size) = usize::try_from(size) {
                         tokio::io::BufWriter::with_capacity(std::cmp::min(size, 1024 * 1024), file)
                     } else {
@@ -744,14 +764,18 @@ pub async fn untar<R: tokio::io::AsyncRead + Unpin>(
 
 /// Unpack a `.zip`, `.tar.gz`, `.tar.bz2`, `.tar.zst`, or `.tar.xz` archive into the target directory,
 /// without requiring `Seek`.
-pub async fn archive<R: tokio::io::AsyncRead + Unpin>(
+///
+/// `source_hint` is used for warning messages, to identify the source of the archive
+/// beneath the reader. It might be a URL, a file path, or something else.
+pub async fn archive<D: Display, R: tokio::io::AsyncRead + Unpin>(
+    source_hint: D,
     reader: R,
     ext: SourceDistExtension,
     target: impl AsRef<Path>,
 ) -> Result<(), Error> {
     match ext {
         SourceDistExtension::Zip => {
-            unzip(reader, target).await?;
+            unzip(source_hint, reader, target).await?;
         }
         SourceDistExtension::Tar => {
             untar(reader, target).await?;
