@@ -318,15 +318,6 @@ async fn perform_install(
         );
     }
 
-    if let PythonUpgrade::Enabled(source @ PythonUpgradeSource::Upgrade) = upgrade {
-        if !preview.is_enabled(PreviewFeature::PythonUpgrade) {
-            warn_user!(
-                "`{source}` is experimental and may change without warning. Pass `--preview-features {}` to disable this warning",
-                PreviewFeature::PythonUpgrade
-            );
-        }
-    }
-
     if default && targets.len() > 1 {
         anyhow::bail!("The `--default` flag cannot be used with multiple targets");
     }
@@ -733,16 +724,7 @@ async fn perform_install(
         );
 
     for installation in minor_versions.values() {
-        if matches!(
-            upgrade,
-            PythonUpgrade::Enabled(PythonUpgradeSource::Upgrade)
-        ) {
-            // During an upgrade, update existing symlinks but avoid
-            // creating new ones.
-            installation.update_minor_version_link(preview)?;
-        } else {
-            installation.ensure_minor_version_link(preview)?;
-        }
+        installation.ensure_minor_version_link()?;
     }
 
     if changelog.installed.is_empty() && errors.is_empty() {
@@ -1015,7 +997,7 @@ fn create_bin_links(
         }
         let executable = if upgradeable {
             if let Some(minor_version_link) =
-                PythonMinorVersionLink::from_installation(installation, preview)
+                PythonMinorVersionLink::from_installation(installation)
             {
                 minor_version_link.symlink_executable.clone()
             } else {
