@@ -6,8 +6,6 @@ use anyhow::{Result, bail};
 use owo_colors::OwoColorize;
 use uv_fs::Simplified;
 use uv_normalize::PackageName;
-use uv_preview::{Preview, PreviewFeature};
-use uv_warnings::warn_user;
 use uv_workspace::{DiscoveryOptions, Workspace, WorkspaceCache};
 
 use crate::commands::ExitStatus;
@@ -17,16 +15,8 @@ use crate::printer::Printer;
 pub(crate) async fn dir(
     package_name: Option<PackageName>,
     project_dir: &Path,
-    preview: Preview,
     printer: Printer,
 ) -> Result<ExitStatus> {
-    if !preview.is_enabled(PreviewFeature::WorkspaceDir) {
-        warn_user!(
-            "The `uv workspace dir` command is experimental and may change without warning. Pass `--preview-features {}` to disable this warning.",
-            PreviewFeature::WorkspaceDir
-        );
-    }
-
     let workspace_cache = WorkspaceCache::default();
     let workspace =
         Workspace::discover(project_dir, &DiscoveryOptions::default(), &workspace_cache).await?;
