@@ -1,4 +1,3 @@
-use crate::common::{TestContext, uv_snapshot, venv_bin_path};
 use anyhow::Result;
 use assert_cmd::assert::OutputAssertExt;
 use assert_fs::fixture::{FileTouch, FileWriteBin, FileWriteStr, PathChild, PathCreateDir};
@@ -11,6 +10,7 @@ use std::path::Path;
 use std::process::Command;
 use tempfile::TempDir;
 use uv_static::EnvVars;
+use uv_test::{uv_snapshot, venv_bin_path};
 
 const BUILT_BY_UV_TEST_SCRIPT: &str = indoc! {r#"
     from built_by_uv import greet
@@ -26,7 +26,7 @@ const BUILT_BY_UV_TEST_SCRIPT: &str = indoc! {r#"
 #[test]
 #[cfg(feature = "test-pypi")]
 fn built_by_uv_direct_wheel() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let built_by_uv = Path::new("../../test/packages/built-by-uv");
 
     let temp_dir = TempDir::new()?;
@@ -82,7 +82,7 @@ fn built_by_uv_direct_wheel() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn built_by_uv_direct() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let built_by_uv = Path::new("../../test/packages/built-by-uv");
 
     let sdist_dir = TempDir::new()?;
@@ -156,7 +156,7 @@ fn built_by_uv_direct() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn built_by_uv_editable() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let built_by_uv = Path::new("../../test/packages/built-by-uv");
 
     // Without the editable, pytest fails.
@@ -217,7 +217,7 @@ fn built_by_uv_editable() -> Result<()> {
 fn preserve_executable_bit() -> Result<()> {
     use std::io::Write;
 
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let project_dir = context.temp_dir.path().join("preserve_executable_bit");
     context
@@ -280,7 +280,7 @@ fn preserve_executable_bit() -> Result<()> {
 /// potential modules.
 #[test]
 fn rename_module() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let temp_dir = TempDir::new()?;
 
     context
@@ -361,7 +361,7 @@ fn rename_module() -> Result<()> {
 /// Test `tool.uv.build-backend.module-name` for editable builds.
 #[test]
 fn rename_module_editable_build() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let temp_dir = TempDir::new()?;
 
     context
@@ -421,7 +421,7 @@ fn rename_module_editable_build() -> Result<()> {
 /// Check that the build succeeds even if the module name mismatches by case.
 #[test]
 fn build_module_name_normalization() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let wheel_dir = context.temp_dir.path().join("dist");
     fs_err::create_dir(&wheel_dir)?;
@@ -535,7 +535,7 @@ fn build_module_name_normalization() -> Result<()> {
 
 #[test]
 fn build_sdist_with_long_path() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let temp_dir = TempDir::new()?;
 
     context
@@ -578,7 +578,7 @@ fn build_sdist_with_long_path() -> Result<()> {
 
 #[test]
 fn sdist_error_without_module() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let temp_dir = TempDir::new()?;
 
     context
@@ -625,7 +625,7 @@ fn sdist_error_without_module() -> Result<()> {
 
 #[test]
 fn complex_namespace_packages() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let dist = context.temp_dir.child("dist");
     dist.create_dir_all()?;
 
@@ -762,7 +762,7 @@ fn complex_namespace_packages() -> Result<()> {
 
 #[test]
 fn license_glob_without_matches_errors() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let project = context.temp_dir.child("missing-license");
     context
@@ -807,7 +807,7 @@ fn license_glob_without_matches_errors() -> Result<()> {
 
 #[test]
 fn license_file_must_be_utf8() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let project = context.temp_dir.child("license-utf8");
     context
@@ -852,7 +852,7 @@ fn license_file_must_be_utf8() -> Result<()> {
 #[test]
 #[cfg(unix)]
 fn symlinked_file() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let project = context.temp_dir.child("project");
     context
@@ -941,7 +941,7 @@ fn symlinked_file() -> Result<()> {
 /// They may be from another `uv_build` version that has a different schema.
 #[test]
 fn invalid_build_backend_settings_are_ignored() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! {r#"
@@ -977,7 +977,7 @@ fn invalid_build_backend_settings_are_ignored() -> Result<()> {
 /// `tool.uv.build-backend.module-root = ".."`.
 #[test]
 fn error_on_relative_module_root_outside_project_root() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! {r#"
@@ -1025,7 +1025,7 @@ fn error_on_relative_module_root_outside_project_root() -> Result<()> {
 /// `tool.uv.build-backend.data.headers = "../headers"`.
 #[test]
 fn error_on_relative_data_dir_outside_project_root() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let project = context.temp_dir.child("project");
     project.create_dir_all()?;
@@ -1079,7 +1079,7 @@ fn error_on_relative_data_dir_outside_project_root() -> Result<()> {
 /// Show an explicit error when there is a venv in source tree.
 #[test]
 fn venv_in_source_tree() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     context
         .init()
@@ -1121,7 +1121,7 @@ fn venv_in_source_tree() {
 /// Show a warning when the build backend is passed redundant module names
 #[test]
 fn warn_on_redundant_module_names() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! {r#"
@@ -1188,7 +1188,7 @@ fn warn_on_redundant_module_names() -> Result<()> {
 
 #[test]
 fn invalid_pyproject_toml() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     context
         .temp_dir
@@ -1226,7 +1226,7 @@ fn invalid_pyproject_toml() -> Result<()> {
 #[cfg(feature = "test-pypi")]
 #[test]
 fn build_with_all_metadata() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let temp_dir = TempDir::new()?;
 
     context
