@@ -1,11 +1,11 @@
 use assert_cmd::assert::OutputAssertExt;
 
-use crate::common::{TestContext, uv_snapshot};
+use uv_test::uv_snapshot;
 
 /// Test that `cache size` returns 0 for an empty cache directory (raw output).
 #[test]
 fn cache_size_empty_raw() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Clean cache first to ensure truly empty state
     context.clean().assert().success();
@@ -23,7 +23,7 @@ fn cache_size_empty_raw() {
 /// Test that `cache size` returns raw bytes after installing packages.
 #[test]
 fn cache_size_with_packages_raw() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install a requirement to populate the cache.
     context.pip_install().arg("iniconfig").assert().success();
@@ -42,7 +42,7 @@ fn cache_size_with_packages_raw() {
 /// Test that `cache size --human` returns human-readable format after installing packages.
 #[test]
 fn cache_size_with_packages_human() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Install a requirement to populate the cache.
     context.pip_install().arg("iniconfig").assert().success();
