@@ -9,11 +9,11 @@ use uv_static::EnvVars;
 #[cfg(unix)]
 use fs_err::os::unix::fs::symlink;
 
-use crate::common::{TestContext, uv_snapshot};
+use uv_test::uv_snapshot;
 
 #[test]
 fn create_venv() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a virtual environment at `.venv`.
     uv_snapshot!(context.filters(), context.venv()
@@ -72,7 +72,7 @@ fn create_venv() {
 
 #[test]
 fn create_venv_313() {
-    let context = TestContext::new_with_versions(&["3.13"]);
+    let context = uv_test::test_context_with_versions!(&["3.13"]);
 
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
@@ -94,7 +94,7 @@ fn create_venv_313() {
 
 #[test]
 fn create_venv_project_environment() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // `uv venv` ignores `UV_PROJECT_ENVIRONMENT` when it's not a project
     uv_snapshot!(context.filters(), context.venv().env(EnvVars::UV_PROJECT_ENVIRONMENT, "foo"), @"
@@ -213,7 +213,7 @@ fn create_venv_project_environment() -> Result<()> {
 #[test]
 fn virtual_empty() -> Result<()> {
     // testing how `uv venv` reacts to a pyproject with no `[project]` and nothing useful to it
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! {r#"
@@ -239,7 +239,7 @@ fn virtual_empty() -> Result<()> {
 fn virtual_dependency_group() -> Result<()> {
     // testing basic `uv venv` functionality
     // when the pyproject.toml is fully virtual (no `[project]`, but `[dependency-groups]` defined)
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! {r#"
@@ -265,7 +265,7 @@ fn virtual_dependency_group() -> Result<()> {
 
 #[test]
 fn create_venv_defaults_to_cwd() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
     uv_snapshot!(context.filters(), context.venv()
         .arg("--python")
         .arg("3.12"), @"
@@ -285,7 +285,7 @@ fn create_venv_defaults_to_cwd() {
 
 #[test]
 fn create_venv_ignores_virtual_env_variable() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
     // We shouldn't care if `VIRTUAL_ENV` is set to an non-existent directory
     // because we ignore virtual environment interpreter sources (we require a system interpreter)
     uv_snapshot!(context.filters(), context.venv()
@@ -304,7 +304,7 @@ fn create_venv_ignores_virtual_env_variable() {
 
 #[test]
 fn create_venv_reads_request_from_python_version_file() {
-    let context = TestContext::new_with_versions(&["3.11", "3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.11", "3.12"]);
 
     // Without the file, we should use the first on the PATH
     uv_snapshot!(context.filters(), context.venv(), @"
@@ -343,7 +343,7 @@ fn create_venv_reads_request_from_python_version_file() {
 
 #[test]
 fn create_venv_reads_request_from_python_versions_file() {
-    let context = TestContext::new_with_versions(&["3.11", "3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.11", "3.12"]);
 
     // Without the file, we should use the first on the PATH
     uv_snapshot!(context.filters(), context.venv(), @"
@@ -382,7 +382,7 @@ fn create_venv_reads_request_from_python_versions_file() {
 
 #[test]
 fn create_venv_respects_pyproject_requires_python() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.11", "3.9", "3.10", "3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.11", "3.9", "3.10", "3.12"]);
 
     // Without a Python requirement, we use the first on the PATH
     uv_snapshot!(context.filters(), context.venv(), @"
@@ -567,7 +567,7 @@ fn create_venv_respects_pyproject_requires_python() -> Result<()> {
 
 #[test]
 fn create_venv_respects_group_requires_python() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.9", "3.10", "3.11", "3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.9", "3.10", "3.11", "3.12"]);
 
     // Without a Python requirement, we use the first on the PATH
     uv_snapshot!(context.filters(), context.venv(), @"
@@ -745,7 +745,7 @@ fn create_venv_respects_group_requires_python() -> Result<()> {
 
 #[test]
 fn create_venv_ignores_missing_pyproject_metadata() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! { r"[tool.no.project.here]" })?;
@@ -769,7 +769,7 @@ fn create_venv_ignores_missing_pyproject_metadata() -> Result<()> {
 
 #[test]
 fn create_venv_warns_user_on_requires_python_discovery_error() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! { r"invalid toml" })?;
@@ -807,7 +807,7 @@ fn create_venv_warns_user_on_requires_python_discovery_error() -> Result<()> {
 
 #[test]
 fn create_venv_explicit_request_takes_priority_over_python_version_file() {
-    let context = TestContext::new_with_versions(&["3.11", "3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.11", "3.12"]);
 
     context
         .temp_dir
@@ -833,7 +833,7 @@ fn create_venv_explicit_request_takes_priority_over_python_version_file() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn seed() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
         .arg("--seed")
@@ -857,7 +857,7 @@ fn seed() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn seed_older_python_version() {
-    let context = TestContext::new_with_versions(&["3.11"]);
+    let context = uv_test::test_context_with_versions!(&["3.11"]);
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
         .arg("--seed")
@@ -882,7 +882,7 @@ fn seed_older_python_version() {
 
 #[test]
 fn create_venv_with_invalid_http_timeout() {
-    let context = TestContext::new_with_versions(&["3.12"]).with_http_timeout("not_a_number");
+    let context = uv_test::test_context_with_versions!(&["3.12"]).with_http_timeout("not_a_number");
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
         .arg("--python")
@@ -898,7 +898,7 @@ fn create_venv_with_invalid_http_timeout() {
 
 #[test]
 fn create_venv_with_invalid_concurrent_installs() {
-    let context = TestContext::new_with_versions(&["3.12"]).with_concurrent_installs("0");
+    let context = uv_test::test_context_with_versions!(&["3.12"]).with_concurrent_installs("0");
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
         .arg("--python")
@@ -914,7 +914,7 @@ fn create_venv_with_invalid_concurrent_installs() {
 
 #[test]
 fn create_venv_unknown_python_minor() {
-    let context = TestContext::new_with_versions(&["3.12"]).with_filtered_python_sources();
+    let context = uv_test::test_context_with_versions!(&["3.12"]).with_filtered_python_sources();
 
     let mut command = context.venv();
     command
@@ -940,7 +940,7 @@ fn create_venv_unknown_python_minor() {
 
 #[test]
 fn create_venv_unknown_python_patch() {
-    let context = TestContext::new_with_versions(&["3.12"]).with_filtered_python_sources();
+    let context = uv_test::test_context_with_versions!(&["3.12"]).with_filtered_python_sources();
 
     let mut command = context.venv();
     command
@@ -967,7 +967,7 @@ fn create_venv_unknown_python_patch() {
 #[cfg(feature = "test-python-patch")]
 #[test]
 fn create_venv_python_patch() {
-    let context = TestContext::new_with_versions(&["3.12.9"]);
+    let context = uv_test::test_context_with_versions!(&["3.12.9"]);
 
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
@@ -989,7 +989,7 @@ fn create_venv_python_patch() {
 
 #[test]
 fn file_exists() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a file at `.venv`. Creating a virtualenv at the same path should fail.
     context.venv.touch()?;
@@ -1015,7 +1015,7 @@ fn file_exists() -> Result<()> {
 
 #[test]
 fn empty_dir_exists() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create an empty directory at `.venv`. Creating a virtualenv at the same path should succeed.
     context.venv.create_dir_all()?;
@@ -1041,7 +1041,7 @@ fn empty_dir_exists() -> Result<()> {
 
 #[test]
 fn non_empty_dir_exists() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a non-empty directory at `.venv`. Creating a virtualenv at the same path should fail,
     // unless `--clear` is specified.
@@ -1086,7 +1086,7 @@ fn non_empty_dir_exists() -> Result<()> {
 
 #[test]
 fn non_empty_dir_exists_allow_existing() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a non-empty directory at `.venv`. Creating a virtualenv at the same path should
     // succeed when `--allow-existing` is specified, but fail when it is not.
@@ -1151,7 +1151,7 @@ fn non_empty_dir_exists_allow_existing() -> Result<()> {
 /// Run `uv venv` followed by `uv venv --allow-existing`.
 #[test]
 fn create_venv_then_allow_existing() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a venv
     uv_snapshot!(context.filters(), context.venv(), @"
@@ -1184,7 +1184,7 @@ fn create_venv_then_allow_existing() {
 #[test]
 #[cfg(windows)]
 fn windows_shims() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.10", "3.9"]);
+    let context = uv_test::test_context_with_versions!(&["3.10", "3.9"]);
     let shim_path = context.temp_dir.child("shim");
 
     let py39 = context
@@ -1230,7 +1230,7 @@ fn windows_shims() -> Result<()> {
 
 #[test]
 fn verify_pyvenv_cfg() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let pyvenv_cfg = context.venv.child("pyvenv.cfg");
 
     context.venv.assert(predicates::path::is_dir());
@@ -1249,7 +1249,7 @@ fn verify_pyvenv_cfg() {
 
 #[test]
 fn verify_pyvenv_cfg_relocatable() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create a virtual environment at `.venv`.
     context
@@ -1310,7 +1310,7 @@ fn verify_pyvenv_cfg_relocatable() {
 /// With `relocatable-envs-default` preview feature, venvs are relocatable by default.
 #[test]
 fn relocatable_envs_default_preview() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create a virtual environment with the preview feature enabled.
     context
@@ -1334,7 +1334,7 @@ fn relocatable_envs_default_preview() {
 /// With `relocatable-envs-default` preview feature, `--no-relocatable` opts out.
 #[test]
 fn relocatable_envs_default_no_relocatable() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create a virtual environment with the preview feature but opt out.
     context
@@ -1359,7 +1359,7 @@ fn relocatable_envs_default_no_relocatable() {
 /// Ensure that a nested virtual environment uses the same `home` directory as the parent.
 #[test]
 fn verify_nested_pyvenv_cfg() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a virtual environment at `.venv`.
     context
@@ -1412,7 +1412,7 @@ fn verify_nested_pyvenv_cfg() -> Result<()> {
 #[test]
 #[cfg(windows)]
 fn path_with_trailing_space_gives_proper_error() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Set a custom cache directory with a trailing space
     let path_with_trailing_slash = format!("{} ", context.cache_dir.path().display());
@@ -1423,7 +1423,7 @@ fn path_with_trailing_space_gives_proper_error() {
         r"CACHEDIR.TAG`: .* \(os error 3\)",
         "CACHEDIR.TAG`: The system cannot find the path specified. (os error 3)",
     ));
-    uv_snapshot!(filters, std::process::Command::new(crate::common::get_bin())
+    uv_snapshot!(filters, std::process::Command::new(uv_test::get_bin!())
         .arg("venv")
         .env(EnvVars::UV_CACHE_DIR, path_with_trailing_slash), @r###"
     success: false
@@ -1448,7 +1448,7 @@ fn create_venv_apostrophe() {
     use std::process::Command;
     use std::process::Stdio;
 
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     let venv_dir = context.temp_dir.join("Testing's");
 
@@ -1495,7 +1495,7 @@ fn create_venv_apostrophe() {
 #[test]
 fn venv_python_preference() {
     let context =
-        TestContext::new_with_versions(&["3.12", "3.11"]).with_versions_as_managed(&["3.12"]);
+        uv_test::test_context_with_versions!(&["3.12", "3.11"]).with_versions_as_managed(&["3.12"]);
 
     // Create a managed interpreter environment
     uv_snapshot!(context.filters(), context.venv(), @"
@@ -1559,7 +1559,7 @@ fn venv_python_preference() {
 #[test]
 #[cfg(unix)]
 fn create_venv_symlink_clear_preservation() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a target directory
     let target_dir = context.temp_dir.child("target");
@@ -1617,7 +1617,7 @@ fn create_venv_symlink_clear_preservation() -> Result<()> {
 #[test]
 #[cfg(unix)]
 fn create_venv_symlink_recreate_preservation() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a target directory
     let target_dir = context.temp_dir.child("target");
@@ -1675,7 +1675,7 @@ fn create_venv_symlink_recreate_preservation() -> Result<()> {
 #[test]
 #[cfg(unix)]
 fn create_venv_nested_symlink_preservation() -> Result<()> {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a target directory
     let target_dir = context.temp_dir.child("target");
@@ -1741,7 +1741,7 @@ fn create_venv_nested_symlink_preservation() -> Result<()> {
 #[test]
 #[cfg(unix)]
 fn create_venv_current_working_directory() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
@@ -1783,7 +1783,7 @@ fn create_venv_current_working_directory() {
 #[test]
 #[cfg(windows)]
 fn create_venv_current_working_directory() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     uv_snapshot!(context.filters(), context.venv()
         .arg(context.venv.as_os_str())
@@ -1821,7 +1821,7 @@ fn create_venv_current_working_directory() {
 
 #[test]
 fn no_clear_with_existing_directory() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a virtual environment first
     uv_snapshot!(context.filters(), context.venv()
@@ -1862,7 +1862,7 @@ fn no_clear_with_existing_directory() {
 
 #[test]
 fn no_clear_with_non_existent_directory() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create with --no-clear on non-existent directory (should succeed)
     uv_snapshot!(context.filters(), context.venv()
@@ -1886,7 +1886,7 @@ fn no_clear_with_non_existent_directory() {
 
 #[test]
 fn no_clear_overrides_clear() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Create a non-empty directory at `.venv`
     context.venv.create_dir_all().unwrap();
@@ -1916,7 +1916,7 @@ fn no_clear_overrides_clear() {
 
 #[test]
 fn no_clear_conflicts_with_allow_existing() {
-    let context = TestContext::new_with_versions(&["3.12"]);
+    let context = uv_test::test_context_with_versions!(&["3.12"]);
 
     // Try to use --no-clear with --allow-existing (should fail)
     uv_snapshot!(context.filters(), context.venv()
