@@ -10,7 +10,7 @@ use indoc::indoc;
 use insta::{assert_json_snapshot, assert_snapshot};
 use serde::{Deserialize, Serialize};
 
-use crate::common::{TestContext, copy_dir_ignore, make_project, uv_snapshot};
+use uv_test::{copy_dir_ignore, make_project, uv_snapshot};
 
 fn workspaces_dir() -> PathBuf {
     env::current_dir()
@@ -26,7 +26,7 @@ fn workspaces_dir() -> PathBuf {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_in_examples_bird_feeder() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -70,7 +70,7 @@ fn test_albatross_in_examples_bird_feeder() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_in_examples() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -111,7 +111,7 @@ fn test_albatross_in_examples() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_just_project() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -152,7 +152,7 @@ fn test_albatross_just_project() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_project_in_excluded() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -228,7 +228,7 @@ fn test_albatross_project_in_excluded() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_root_workspace() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -272,7 +272,7 @@ fn test_albatross_root_workspace() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_root_workspace_bird_feeder() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -318,7 +318,7 @@ fn test_albatross_root_workspace_bird_feeder() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_root_workspace_albatross() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -364,7 +364,7 @@ fn test_albatross_root_workspace_albatross() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_albatross_virtual_workspace() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let workspace = context.temp_dir.child("workspace");
 
     copy_dir_ignore(workspaces_dir(), &workspace).unwrap();
@@ -412,7 +412,7 @@ fn test_albatross_virtual_workspace() {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_uv_run_with_package_virtual_workspace() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let work_dir = context.temp_dir.join("albatross-virtual-workspace");
 
     copy_dir_ignore(
@@ -482,7 +482,7 @@ fn test_uv_run_with_package_virtual_workspace() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_uv_run_virtual_workspace_root() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let work_dir = context.temp_dir.join("albatross-virtual-workspace");
 
     copy_dir_ignore(
@@ -523,7 +523,7 @@ fn test_uv_run_virtual_workspace_root() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_uv_run_with_package_root_workspace() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let work_dir = context.temp_dir.join("albatross-root-workspace");
 
     copy_dir_ignore(workspaces_dir().join("albatross-root-workspace"), &work_dir)?;
@@ -586,7 +586,7 @@ fn test_uv_run_with_package_root_workspace() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn test_uv_run_isolate() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
     let work_dir = context.temp_dir.join("albatross-root-workspace");
 
     copy_dir_ignore(workspaces_dir().join("albatross-root-workspace"), &work_dir)?;
@@ -682,7 +682,7 @@ fn workspace_lock_idempotence(workspace: &str, subdirectories: &[&str]) -> Resul
     let mut shared_lock = None;
 
     for dir in subdirectories {
-        let context = TestContext::new("3.12");
+        let context = uv_test::test_context!("3.12");
         let work_dir = context.temp_dir.join(workspace);
 
         copy_dir_ignore(workspaces_dir().join(workspace), &work_dir)?;
@@ -759,7 +759,7 @@ struct Package {
 /// `e`. We have `a -> b`, `b -> c`, `c -> d`. `e` should not be installed.
 #[test]
 fn workspace_to_workspace_paths_dependencies() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build the main workspace ...
     let main_workspace = context.temp_dir.child("main-workspace");
@@ -852,10 +852,10 @@ fn workspace_to_workspace_paths_dependencies() -> Result<()> {
     Ok(())
 }
 
-/// Ensure that workspace discovery errors if a member is missing a `pyproject.toml`.
+/// Ensure that workspace discovery skips an empty directory that matches a member glob.
 #[test]
 fn workspace_empty_member() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build the main workspace ...
     let workspace = context.temp_dir.child("workspace");
@@ -881,6 +881,192 @@ fn workspace_empty_member() -> Result<()> {
     // ... and an empty c.
     fs_err::create_dir_all(workspace.join("packages").join("c"))?;
 
+    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
+    Resolved 2 packages in [TIME]
+    "
+    );
+
+    Ok(())
+}
+
+/// Ensure that workspace discovery skips directories that only contain gitignored files.
+#[test]
+fn workspace_gitignored_member() -> Result<()> {
+    let context = uv_test::test_context!("3.12");
+
+    // Build the main workspace ...
+    let workspace = context.temp_dir.child("workspace");
+    workspace.child("pyproject.toml").write_str(indoc! {r#"
+        [tool.uv.workspace]
+        members = ["packages/*"]
+    "#})?;
+
+    // ... with a `.gitignore` that ignores `__pycache__` ...
+    workspace.child(".gitignore").write_str("__pycache__/\n")?;
+
+    // ... with a  ...
+    let deps = indoc! {r#"
+        dependencies = ["b"]
+
+        [tool.uv.sources]
+        b = { workspace = true }
+    "#};
+    make_project(&workspace.join("packages").join("a"), "a", deps)?;
+
+    // ... and b.
+    let deps = indoc! {r"
+    "};
+    make_project(&workspace.join("packages").join("b"), "b", deps)?;
+
+    // ... and a c that only contains gitignored files.
+    fs_err::create_dir_all(workspace.join("packages").join("c").join("__pycache__"))?;
+    fs_err::write(
+        workspace
+            .join("packages")
+            .join("c")
+            .join("__pycache__")
+            .join("test.cpython-312.pyc"),
+        "fake",
+    )?;
+
+    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
+    Resolved 2 packages in [TIME]
+    "
+    );
+
+    let lock: SourceLock = toml::from_str(&fs_err::read_to_string(workspace.join("uv.lock"))?)?;
+
+    assert_json_snapshot!(lock.sources(), @r#"
+    {
+      "a": {
+        "editable": "packages/a"
+      },
+      "b": {
+        "editable": "packages/b"
+      }
+    }
+    "#);
+
+    Ok(())
+}
+
+/// Ensure that workspace discovery skips directories that only contain files ignored via
+/// `.ignore` (not just `.gitignore`).
+#[test]
+fn workspace_ignored_member() -> Result<()> {
+    let context = uv_test::test_context!("3.12");
+
+    // Build the main workspace ...
+    let workspace = context.temp_dir.child("workspace");
+    workspace.child("pyproject.toml").write_str(indoc! {r#"
+        [tool.uv.workspace]
+        members = ["packages/*"]
+    "#})?;
+
+    // ... with an `.ignore` file that ignores `__pycache__` ...
+    workspace.child(".ignore").write_str("__pycache__/\n")?;
+
+    // ... with a  ...
+    let deps = indoc! {r#"
+        dependencies = ["b"]
+
+        [tool.uv.sources]
+        b = { workspace = true }
+    "#};
+    make_project(&workspace.join("packages").join("a"), "a", deps)?;
+
+    // ... and b.
+    let deps = indoc! {r"
+    "};
+    make_project(&workspace.join("packages").join("b"), "b", deps)?;
+
+    // ... and a c that only contains ignored files.
+    fs_err::create_dir_all(workspace.join("packages").join("c").join("__pycache__"))?;
+    fs_err::write(
+        workspace
+            .join("packages")
+            .join("c")
+            .join("__pycache__")
+            .join("test.cpython-312.pyc"),
+        "fake",
+    )?;
+
+    uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
+    Resolved 2 packages in [TIME]
+    "
+    );
+
+    let lock: SourceLock = toml::from_str(&fs_err::read_to_string(workspace.join("uv.lock"))?)?;
+
+    assert_json_snapshot!(lock.sources(), @r#"
+    {
+      "a": {
+        "editable": "packages/a"
+      },
+      "b": {
+        "editable": "packages/b"
+      }
+    }
+    "#);
+
+    Ok(())
+}
+
+/// Ensure that workspace discovery still errors for non-empty, non-gitignored directories
+/// missing a `pyproject.toml`.
+#[test]
+fn workspace_nonempty_member_no_pyproject() -> Result<()> {
+    let context = uv_test::test_context!("3.12");
+
+    // Build the main workspace ...
+    let workspace = context.temp_dir.child("workspace");
+    workspace.child("pyproject.toml").write_str(indoc! {r#"
+        [tool.uv.workspace]
+        members = ["packages/*"]
+    "#})?;
+
+    // ... with a `.gitignore` that ignores `__pycache__` ...
+    workspace.child(".gitignore").write_str("__pycache__/\n")?;
+
+    // ... with a  ...
+    let deps = indoc! {r#"
+        dependencies = ["b"]
+
+        [tool.uv.sources]
+        b = { workspace = true }
+    "#};
+    make_project(&workspace.join("packages").join("a"), "a", deps)?;
+
+    // ... and b.
+    let deps = indoc! {r"
+    "};
+    make_project(&workspace.join("packages").join("b"), "b", deps)?;
+
+    // ... and a c that contains non-gitignored files but no `pyproject.toml`.
+    fs_err::create_dir_all(workspace.join("packages").join("c"))?;
+    fs_err::write(
+        workspace.join("packages").join("c").join("README.md"),
+        "# Hello",
+    )?;
+
     uv_snapshot!(context.filters(), context.lock().current_dir(&workspace), @"
     success: false
     exit_code: 2
@@ -897,7 +1083,7 @@ fn workspace_empty_member() -> Result<()> {
 /// Ensure that workspace discovery ignores hidden directories.
 #[test]
 fn workspace_hidden_files() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build the main workspace ...
     let workspace = context.temp_dir.child("workspace");
@@ -953,7 +1139,7 @@ fn workspace_hidden_files() -> Result<()> {
 /// Ensure that workspace discovery accepts valid hidden directories.
 #[test]
 fn workspace_hidden_member() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build the main workspace ...
     let workspace = context.temp_dir.child("workspace");
@@ -1019,7 +1205,7 @@ fn workspace_hidden_member() -> Result<()> {
 /// Ensure that workspace discovery accepts valid hidden directories.
 #[test]
 fn workspace_non_included_member() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build the main workspace ...
     let workspace = context.temp_dir.child("workspace");
@@ -1082,7 +1268,7 @@ fn workspace_non_included_member() -> Result<()> {
 /// relative to the member.
 #[test]
 fn workspace_inherit_sources() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create the workspace root.
     let workspace = context.temp_dir.child("workspace");
@@ -1316,7 +1502,7 @@ fn workspace_inherit_sources() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn workspace_unsatisfiable_member_dependencies() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create the workspace root.
     let workspace = context.temp_dir.child("workspace");
@@ -1372,7 +1558,7 @@ fn workspace_unsatisfiable_member_dependencies() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn workspace_unsatisfiable_member_dependencies_conflicting() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create the workspace root.
     let workspace = context.temp_dir.child("workspace");
@@ -1440,7 +1626,7 @@ fn workspace_unsatisfiable_member_dependencies_conflicting() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn workspace_unsatisfiable_member_dependencies_conflicting_threeway() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create the workspace root.
     let workspace = context.temp_dir.child("workspace");
@@ -1523,7 +1709,7 @@ fn workspace_unsatisfiable_member_dependencies_conflicting_threeway() -> Result<
 #[test]
 #[cfg(feature = "test-pypi")]
 fn workspace_unsatisfiable_member_dependencies_conflicting_extra() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create the workspace root.
     let workspace = context.temp_dir.child("workspace");
@@ -1593,7 +1779,7 @@ fn workspace_unsatisfiable_member_dependencies_conflicting_extra() -> Result<()>
 #[test]
 #[cfg(feature = "test-pypi")]
 fn workspace_unsatisfiable_member_dependencies_conflicting_dev() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create the workspace root.
     let workspace = context.temp_dir.child("workspace");
@@ -1664,7 +1850,7 @@ fn workspace_unsatisfiable_member_dependencies_conflicting_dev() -> Result<()> {
 #[test]
 #[cfg(feature = "test-pypi")]
 fn workspace_member_name_shadows_dependencies() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create the workspace root.
     let workspace = context.temp_dir.child("workspace");
@@ -1736,7 +1922,7 @@ fn workspace_member_name_shadows_dependencies() -> Result<()> {
 /// the paths don't line up by accident.
 #[test]
 fn test_path_hopping() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build the main project ...
     let deps = indoc! {r#"
@@ -1794,7 +1980,7 @@ fn test_path_hopping() -> Result<()> {
 #[test]
 #[cfg(feature = "test-git")]
 fn transitive_dep_in_git_workspace_no_root() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1869,7 +2055,7 @@ fn transitive_dep_in_git_workspace_no_root() -> Result<()> {
 #[test]
 #[cfg(feature = "test-git")]
 fn transitive_dep_in_git_workspace_with_root() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(
@@ -1934,7 +2120,7 @@ fn transitive_dep_in_git_workspace_with_root() -> Result<()> {
 
 #[test]
 fn workspace_members_with_leading_dot_slash() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build the main workspace with leading `./` in member paths
     let workspace = context.temp_dir.child("workspace");
@@ -2004,7 +2190,7 @@ fn workspace_members_with_leading_dot_slash() -> Result<()> {
 
 #[test]
 fn workspace_members_with_parent_directory() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build a workspace with a member outside its directory using `../`
     let workspace = context.temp_dir.child("workspace");
@@ -2049,7 +2235,7 @@ fn workspace_members_with_parent_directory() -> Result<()> {
 
 #[test]
 fn workspace_members_with_complex_relative_paths() -> Result<()> {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Build a workspace with complex relative path normalization
     let workspace = context.temp_dir.child("workspace");
@@ -2091,3 +2277,50 @@ fn workspace_members_with_complex_relative_paths() -> Result<()> {
 
     Ok(())
 }
+
+/// Ensure that an unmanaged workspace member without a `[project]` section doesn't panic.
+///
+/// Uses `--verbose` to exercise the `debug!` log path, which previously panicked on
+/// `.unwrap()` when the `[project]` section was missing.
+#[test]
+fn workspace_unmanaged_member_no_project() -> Result<()> {
+    let context = uv_test::test_context!("3.12");
+
+    let workspace = context.temp_dir.child("workspace");
+    workspace.child("pyproject.toml").write_str(indoc! {r#"
+        [project]
+        name = "root"
+        version = "0.1.0"
+        requires-python = ">=3.12"
+
+        [tool.uv.workspace]
+        members = ["member"]
+
+        [build-system]
+        requires = ["uv_build>=0.9.0,<10000"]
+        build-backend = "uv_build"
+    "#})?;
+
+    fs_err::create_dir_all(workspace.join("src").join("root"))?;
+    fs_err::write(workspace.join("src").join("root").join("__init__.py"), "")?;
+
+    // Create a workspace member with `managed = false` but no `[project]` section.
+    let member = workspace.join("member");
+    fs_err::create_dir_all(&member)?;
+    fs_err::write(
+        member.join("pyproject.toml"),
+        indoc! {"
+            [tool.uv]
+            managed = false
+        "},
+    )?;
+
+    context
+        .lock()
+        .arg("--verbose")
+        .current_dir(&workspace)
+        .assert()
+        .success();
+
+    Ok(())
+}
